@@ -138,6 +138,7 @@ class ConstructHub(
         alarm_actions: AlarmActions,
         dashboard_name: typing.Optional[builtins.str] = None,
         domain: typing.Optional["Domain"] = None,
+        isolate_lambdas: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
         :param scope: -
@@ -145,11 +146,15 @@ class ConstructHub(
         :param alarm_actions: (experimental) Actions to perform when alarms are set.
         :param dashboard_name: (experimental) The name of the CloudWatch Dashboard created to observe this application. Must only contain alphanumerics, dash (-) and underscore (_). Default: "construct-hub"
         :param domain: (experimental) Connect the hub to a domain (requires a hosted zone and a certificate).
+        :param isolate_lambdas: (experimental) Whether sensitive Lambda functions (which operate on un-trusted complex data, such as the transliterator, which operates with externally-sourced npm package tarballs) should run in network-isolated environments. This implies the creation of additonal resources, including: - A VPC with only isolated subnets. - VPC Endpoints (CodeArtifact, CodeArtifact API, S3) - A CodeArtifact Repository with an external connection to npmjs.com Default: true
 
         :stability: experimental
         '''
         props = ConstructHubProps(
-            alarm_actions=alarm_actions, dashboard_name=dashboard_name, domain=domain
+            alarm_actions=alarm_actions,
+            dashboard_name=dashboard_name,
+            domain=domain,
+            isolate_lambdas=isolate_lambdas,
         )
 
         jsii.create(ConstructHub, self, [scope, id, props])
@@ -179,6 +184,7 @@ class ConstructHub(
         "alarm_actions": "alarmActions",
         "dashboard_name": "dashboardName",
         "domain": "domain",
+        "isolate_lambdas": "isolateLambdas",
     },
 )
 class ConstructHubProps:
@@ -188,12 +194,14 @@ class ConstructHubProps:
         alarm_actions: AlarmActions,
         dashboard_name: typing.Optional[builtins.str] = None,
         domain: typing.Optional["Domain"] = None,
+        isolate_lambdas: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''(experimental) Props for ``ConstructHub``.
 
         :param alarm_actions: (experimental) Actions to perform when alarms are set.
         :param dashboard_name: (experimental) The name of the CloudWatch Dashboard created to observe this application. Must only contain alphanumerics, dash (-) and underscore (_). Default: "construct-hub"
         :param domain: (experimental) Connect the hub to a domain (requires a hosted zone and a certificate).
+        :param isolate_lambdas: (experimental) Whether sensitive Lambda functions (which operate on un-trusted complex data, such as the transliterator, which operates with externally-sourced npm package tarballs) should run in network-isolated environments. This implies the creation of additonal resources, including: - A VPC with only isolated subnets. - VPC Endpoints (CodeArtifact, CodeArtifact API, S3) - A CodeArtifact Repository with an external connection to npmjs.com Default: true
 
         :stability: experimental
         '''
@@ -208,6 +216,8 @@ class ConstructHubProps:
             self._values["dashboard_name"] = dashboard_name
         if domain is not None:
             self._values["domain"] = domain
+        if isolate_lambdas is not None:
+            self._values["isolate_lambdas"] = isolate_lambdas
 
     @builtins.property
     def alarm_actions(self) -> AlarmActions:
@@ -241,6 +251,24 @@ class ConstructHubProps:
         result = self._values.get("domain")
         return typing.cast(typing.Optional["Domain"], result)
 
+    @builtins.property
+    def isolate_lambdas(self) -> typing.Optional[builtins.bool]:
+        '''(experimental) Whether sensitive Lambda functions (which operate on un-trusted complex data, such as the transliterator, which operates with externally-sourced npm package tarballs) should run in network-isolated environments.
+
+        This
+        implies the creation of additonal resources, including:
+
+        - A VPC with only isolated subnets.
+        - VPC Endpoints (CodeArtifact, CodeArtifact API, S3)
+        - A CodeArtifact Repository with an external connection to npmjs.com
+
+        :default: true
+
+        :stability: experimental
+        '''
+        result = self._values.get("isolate_lambdas")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
