@@ -28,6 +28,8 @@ import aws_cdk.aws_s3_deployment._jsii
 import aws_cdk.aws_s3_notifications._jsii
 import aws_cdk.aws_sns._jsii
 import aws_cdk.aws_sqs._jsii
+import aws_cdk.aws_stepfunctions._jsii
+import aws_cdk.aws_stepfunctions_tasks._jsii
 import aws_cdk.core._jsii
 import aws_cdk.custom_resources._jsii
 import aws_cdk.cx_api._jsii
@@ -35,7 +37,7 @@ import cdk_watchful._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "construct-hub", "0.1.96", __name__[0:-6], "construct-hub@0.1.96.jsii.tgz"
+    "construct-hub", "0.1.103", __name__[0:-6], "construct-hub@0.1.103.jsii.tgz"
 )
 
 __all__ = [
